Code Documentation
==================

.. toctree::
   :maxdepth: 2

Models
------

.. automodule:: djiffy.models
    :members:

Views
-----

.. automodule:: djiffy.views
    :members:

Import
------

.. automodule:: djiffy.importer
    :members:

Manage Commands
---------------

Import manifest
^^^^^^^^^^^^^^^

.. automodule:: djiffy.management.commands.import_manifest
    :members: